
def help_mi():
    print("эта библиотека состоит из двух модулей, 1-все вычисления с факториалами(дискретная математика), 2 модуль считает значение строки")
    print('у нас есть функции(модуль math): ')
    print('factorial(n)-Вычисляет факториал числа `n`')
    print('permutation(n)-Возвращает количество перестановок для `n` объектов')
    print('compination(n, k)- Вычисляет количество комбинаций (выборов) из `n` объектов по `k` без учета порядка')
    print('binkof(n, k)- Вычисляет биномиальный коэффициент')
    print('gamma(n)- Возвращает значение функции гамма для `n`')
    print('summaf(n)- Вычисляет сумму факториалов всех целых чисел от 1 до `n`')
    print(' ')
    print(' ')
    print('у нас есть функции(модуль str_op): ')
    print('Task.evaluate("n-u*p/n")-любая формула')
    